import fetch from 'node-fetch';
import 'dotenv/config';
import express from "express";
import cors from 'cors';
import log4js from 'log4js';
import path from 'path';

import * as paypal from "./paypal-api.js";
const {PORT = 8888} = process.env;

/*
import { fileURLToPath } from 'url';
import { dirname } from 'path';
const __filename = fileURLToPath(import.meta.url);
const __dirname = dirname(__filename);
log4js.configure({
  appenders: { everything: { type: 'file', filename: 'logs.log' } },
  categories: { default: { appenders: ['everything'], level: 'ALL' } }
});
const logger = log4js.getLogger();
*/


const app = express();
app.set("view engine", "ejs");
app.use(
  cors({
    origin: 'https://communityservices.directoryofaustralia.com.au',
  })
);
app.use(express.static("public"));
app.use(express.json());

global.purchaseAmount = "0";
const version = "1.7";


// render checkout page with client id & unique client token
app.get("/", async (req, res) => {
	const clientId = process.env.PAYPAL_CLIENT_ID;
	const merchantId = process.env.PAYPAL_MERCHANT_ID;
	const clientSecret = process.env.PAYPAL_CLIENT_SECRET;
	try {
		if (!clientId || !merchantId ||  !clientSecret){
			throw new Error("Client Id or App Secret or Merchant Id is missing." + clientId + " <--");
		}
		const clientToken = await paypal.generateClientToken();
		res.render("checkout", { clientId, clientToken, merchantId });
	} catch (err) {
		res.status(500).send(err.message);
	}
});

// create order
app.post("/api/orders", async (req, res) => {
	purchaseAmount = req.body.purchase_units[0]['amount'].value;
	//logger.debug("Requesting..: " + purchaseAmount);
	console.log("Requesting..: " + purchaseAmount);
	try {
		const order = await paypal.createOrder();
		res.json(order);
	} catch (err) {
		res.status(500).send(err.message);
	}
});

// Get order
app.post("/api/orders/:orderID", async (req, res) => {
	const { orderID } = req.params;
	try {
		const order = await paypal.getOrder(orderID);
		res.json(order);
	} catch (err) {
		res.status(500).send(err.message);
	}
});

// capture payment
app.post("/api/orders/:orderID/capture", async (req, res) => {
	const { orderID } = req.params;
	try {
		const captureData = await paypal.capturePayment(orderID);
		res.json(captureData);
	} catch (err) {
		res.status(500).send(err.message);
	}
});

// check order
app.post("/api/orders/:orderID/transactions", async (req, res) => {
	const { orderID } = req.params;
	console.log("OrderID.....: " + orderID);
	try {
		const captureData = await paypal.getTransaction(orderID);
		res.json(captureData);
	} catch (err) {
		res.status(500).send(err.message);
	}
});

// health check
app.get("/check" ,(req,res) => {
	res.json({
		message: "ok",
		env: process.env.NODE_ENV, 
		baseUrl: process.env.BASE_URL
	})
})
/*app.get('/logs', (req, res) => {
	res.sendFile(path.join(__dirname + '/logs.log'));

});*/

app.listen(PORT, () => {
	//logger.debug(`Server listening at http://localhost:${PORT}/ - Version ${version}`);
	//console.log(`Server listening at http://localhost:${PORT}/ - Version ${version}`);
});

